"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.postRuntimeEventResponse = exports.getRuntimeEvent = exports.endpointProxy = exports.endpointSpawn = exports.run = void 0;
const events_1 = require("./internal/events");
const endpoints_1 = require("./internal/endpoints");
Object.defineProperty(exports, "endpointSpawn", { enumerable: true, get: function () { return endpoints_1.endpointSpawn; } });
Object.defineProperty(exports, "endpointProxy", { enumerable: true, get: function () { return endpoints_1.endpointProxy; } });
const log_1 = require("./internal/log");
const runtime_1 = require("./internal/runtime");
Object.defineProperty(exports, "getRuntimeEvent", { enumerable: true, get: function () { return runtime_1.getRuntimeEvent; } });
Object.defineProperty(exports, "postRuntimeEventResponse", { enumerable: true, get: function () { return runtime_1.postRuntimeEventResponse; } });
const { _HANDLER, AWS_LAMBDA_RUNTIME_API } = process.env;
const run = async () => {
    if (!AWS_LAMBDA_RUNTIME_API) {
        throw new Error("No AWS_LAMBDA_RUNTIME_API specified");
    }
    if (!_HANDLER) {
        throw new Error("No handler specified");
    }
    (0, log_1.log)("Bootstraping", { _HANDLER, AWS_LAMBDA_RUNTIME_API });
    const { childProcess, bin, endpoint } = await (0, endpoints_1.endpointSpawn)(_HANDLER, process.env);
    try {
        (0, log_1.log)("Polling for events", { bin, endpoint });
        await (0, events_1.pollForEvents)(AWS_LAMBDA_RUNTIME_API, bin, endpoint);
    }
    catch (e) {
        if (childProcess) {
            (0, log_1.log)("Killing child process", { pid: childProcess.pid });
            childProcess.kill();
        }
        throw e;
    }
};
exports.run = run;
